#!/bin/bash
# Start apnginx container

set -exou pipefail

# Set variables. 
# APDOCKER_DOMAIN is set in from the systemd .service file
APLINUX_REGISTRY="aplinux-microsoft.azurecr.io${APDOCKER_DOMAIN}"
APNGINX_IMAGE=${APLINUX_REGISTRY}/apnginx:0.1.0-dev

# Pull a fresh ACR connection config every start
# We'll only capture stdout to ACR_CONNECTION_STRING, which will be empty on failure
ACR_CONNECTION_STRING=$(../aptools/apsecret_refresh_acr.py)
if [ $? -ne 0 ]
then
    echo "WARNING: Could not grab the most recent connection configuration for ACR."
fi

if [ -z "${ACR_CONNECTION_STRING}" ]
then
    echo "ERROR: Could not read the cached connection configuration for ACR."
    exit -1
fi

# Turn the connection string into an array
ACR_CONFIG=( ${ACR_CONNECTION_STRING} )
ACR_CLIENT_ID="${ACR_CONFIG[0]}"
ACR_CLIENT_KEY="${ACR_CONFIG[1]}"

if [ -z "${ACR_CLIENT_ID}" ] || [ -z "${ACR_CLIENT_KEY}" ]
then
    echo "ERROR: Invalid connection configuration cached for ACR."
    exit -1
fi

# Don't bother logging in and pulling the image if its already been done
if [[ "$(docker images -q ${APNGINX_IMAGE} 2> /dev/null)" == "" ]]
then
    # Login to aplinux registry and pull the image
    docker login -u ${ACR_CLIENT_ID} -p ${ACR_CLIENT_KEY} ${APLINUX_REGISTRY}
    docker pull ${APNGINX_IMAGE}
    docker logout "${APLINUX_REGISTRY}"
fi

# Get the container up and automatically clean it up on exit
docker run --rm --name=apnginx -h 127.0.0.1 -p 6798:6798 -p 6698:6698 -v /ap/data/certs/machine_function:/certs ${APNGINX_IMAGE} /start.sh

